@@ -361,7 +361,7 @@ on_button_press (GooCanvasItem *item,
 
 	  fleur = gdk_cursor_new (GDK_FLEUR);
 	  goo_canvas_pointer_grab (canvas, item,
-				   GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
+				   GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE_MASK,
 				   fleur,
 				   event->time);
 	  gdk_cursor_unref (fleur);
@@ -412,6 +412,7 @@ on_background_button_press (GooCanvasItem *item,
 			    gpointer data)
 {
   GooCanvas *canvas;
+  GList *items, *elem;
 
 #if 1
   g_print ("background received 'button-press' signal\n");
@@ -420,6 +421,12 @@ on_background_button_press (GooCanvasItem *item,
   canvas = goo_canvas_item_get_canvas (item);
   output_items_in_area (canvas, event->x_root, event->y_root);
 
+  items = goo_canvas_get_items_at (canvas, event->x_root, event->y_root,
+				   FALSE);
+  for (elem = items; elem; elem = elem->next)
+    g_print ("  clicked items: %p\n", elem->data);
+  g_list_free (items);
+
   return TRUE;
 }
 
@@ -466,6 +473,9 @@ create_canvas_primitives ()
 		      "bounds-from-origin", FALSE,
 		      "bounds-padding", 4.0,
 		      "background-color-rgb", 0xC3C3FF,
+#if 0
+		      "redraw-when-scrolled", TRUE,
+#endif
 		      NULL);
 	goo_canvas_set_bounds (GOO_CANVAS (canvas), 0, 0, 604, 454);
 
@@ -1319,6 +1329,44 @@ setup_images (GooCanvasItem *root)
 }
 
 
+static void
+setup_static_items (GooCanvas *canvas)
+{
+  GooCanvasItem *static_root, *group, *item;
+
+  static_root = goo_canvas_get_static_root_item (canvas);
+
+  /* All static items in one place in the canvas should be placed in the same
+     group. */
+  group = goo_canvas_group_new (static_root, NULL);
+
+  item = goo_canvas_polyline_new_line (group,
+				       40.0, 410.0,
+				       40.0, 330.0,
+				       "stroke-color", "midnightblue",
+				       "line-width", 3.0,
+				       "end-arrow", TRUE,
+				       "arrow-tip-length", 3.0,
+				       "arrow-length", 4.0,
+				       "arrow-width", 3.5,
+				       NULL);
+  setup_item_signals (item);
+
+  item = goo_canvas_polyline_new_line (group,
+				       32.0, 370.0,
+				       48.0, 370.0,
+				       "stroke-color", "midnightblue",
+				       "line-width", 3.0,
+				       NULL);
+  setup_item_signals (item);
+
+  item = goo_canvas_text_new (group, "N", 40, 320, -1, GTK_ANCHOR_S,
+			      "font", "Sans 12",
+			      NULL);
+  setup_item_signals (item);
+}
+
+
 /* This checks that the rgba color properties work properly, i.e. the value
    written to them is the same when read back out. */
 static void
@@ -1397,6 +1445,25 @@ test_simple_transforms (GooCanvasItem *root)
 #endif
 }
 
+
+static void
+setup_grids (GooCanvasItem *root)
+{
+  GooCanvasItem *item;
+
+  item = goo_canvas_grid_new (root, 80, 310, 90, 90, 10, 10, 5, 5,
+			      "stroke-color", "yellow",
+			      "fill-color", "pink",
+			      "border-width", 2.0,
+			      "border-color", "red",
+			      "vert-grid-line-color", "lightblue",
+			      "horz-grid-line-width", 1.0,
+			      "vert-grid-line-width", 1.0,
+			      "vert-grid-lines-on-top", TRUE,
+			      NULL);
+}
+
+
 static void
 setup_canvas (GooCanvas *canvas)
 {
@@ -1416,6 +1483,8 @@ setup_canvas (GooCanvas *canvas)
   setup_texts (root); 
   setup_images (root);
   setup_invisible_texts (root);
+  setup_static_items (canvas);
+  setup_grids (root);
 #endif
 
   test_color_properties (root);
